]> git.cworth.org Git - empires-server/blobdiff - lmno.js
Remove debugging log message
[empires-server] / lmno.js
diff --git a/lmno.js b/lmno.js
index abcdba2ef220bd6aff8375bb3190d0cfbc87c727..7c374eff600b32e5da09eedf9657b2732bb63114 100644 (file)
--- a/lmno.js
+++ b/lmno.js
@@ -4,6 +4,7 @@ const body_parser = require("body-parser");
 const session = require("express-session");
 const bcrypt = require("bcrypt");
 const path = require("path");
+const nunjucks = require("nunjucks");
 
 try {
   var lmno_config = require("./lmno-config.json");
@@ -40,8 +41,16 @@ app.use(session({
   saveUninitialized: false
 }));
 
+nunjucks.configure("templates", {
+  autoescape: true,
+  express: app
+});
+
 /* Load each of our game mini-apps. */
-var empires = require("./empires");
+const engines = {
+  empires: require("./empires"),
+  tictactoe: require("./tictactoe")
+};
 
 class LMNO {
   constructor() {
@@ -49,20 +58,22 @@ class LMNO {
   }
 
   generate_id() {
-    return [null,null,null,null].map(() => LMNO.letters.charAt(Math.floor(Math.random() * LMNO.letters.length))).join('');
+    return Array(4).fill(null).map(() => LMNO.letters.charAt(Math.floor(Math.random() * LMNO.letters.length))).join('');
   }
 
-  create_game(engine) {
+  create_game(engine_name) {
     do {
       var id = this.generate_id();
     } while (id in this.ids);
 
-    const game = new empires.Game();
+    const engine = engines[engine_name];
+
+    const game = new engine.Game();
 
     this.ids[id] = {
-       id: id,
-       engine: engine,
-       game: game
+      id: id,
+      engine: engine.name,
+      game: game
     };
 
     return id;
@@ -130,14 +141,20 @@ app.get('/[a-zA-Z0-9]{4}', (request, response) => {
 });
 
 /* LMNO middleware to lookup the game. */
-app.use('/empires/:game_id([a-zA-Z0-9]{4})', (request, response, next) => {
+app.use('/:engine([^/]+)/:game_id([a-zA-Z0-9]{4})', (request, response, next) => {
+  const engine = request.params.engine;
   const game_id = request.params.game_id;
   const canon_id = lmno_canonize(game_id);
 
-  /* Redirect user to page with the canonical ID in it. */
-  if (game_id !== canon_id) {
-    const new_url = request.originalUrl.replace("/empires/" + game_id,
-                                                "/empires/" + canon_id);
+  /* Redirect user to page with the canonical ID in it, also ensuring
+   * that the game ID is _always_ followed by a slash. */
+  const has_slash = new RegExp(`^/${engine}/${game_id}/`);
+  if (game_id !== canon_id ||
+      ! has_slash.test(request.originalUrl))
+  {
+    const old_path = new RegExp(`/${engine}/${game_id}/?`);
+    const new_path = `/${engine}/${canon_id}/`;
+    const new_url = request.originalUrl.replace(old_path, new_path);
     response.redirect(301, new_url);
     return;
   }
@@ -174,6 +191,7 @@ function auth_admin(request, response, next) {
 
 app.get('/logout', (request, response) => {
   request.session.user = undefined;
+  request.session.destroy();
 
   response.send("You are now logged out.");
 });
@@ -184,7 +202,7 @@ app.get('/login', (request, response) => {
     return;
   }
 
-  response.sendFile(path.join(__dirname, './login.html'));
+  response.render('login.html');
 });
 
 app.post('/login', async (request, response) => {
@@ -205,24 +223,36 @@ app.post('/login', async (request, response) => {
   return;
 });
 
-/* A stats page (only available to admin users) */
-app.get('/stats/', auth_admin, (request, response) => {
-  let active = 0;
-  let idle = 0;
+/* API to set uer profile information */
+app.put('/profile', (request, response) => {
+  const nickname = request.body.nickname;
+  if (nickname) {
+    request.session.nickname = nickname;
+    request.session.save();
+  }
+  response.send();
+});
+
+/* An admin page (only available to admin users, of course) */
+app.get('/admin/', auth_admin, (request, response) => {
+  let active = [];
+  let idle = [];
 
   for (let id in lmno.ids) {
     if (lmno.ids[id].game.clients.length)
-      active++;
-   else
-      idle++;
+      active.push(lmno.ids[id]);
+    else
+      idle.push(lmno.ids[id]);
   }
-  response.send(`<html><body>Active games: ${active}.<br>
-Idle games: ${idle}</body></html>`);
+  response.render('admin.html', { test: "foobar", games: { active: active, idle: idle}});
 });
 
 
 /* Mount sub apps. only _after_ we have done all the middleware we need. */
-app.use('/empires/[a-zA-Z0-9]{4}/', empires.app);
+for (let key in engines) {
+  const engine = engines[key];
+  app.use(`/${engine.name}/[a-zA-Z0-9]{4}/`, engine.app);
+}
 
 app.listen(4000, function () {
   console.log('LMNO server listening on localhost:4000');